# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class RetailMode_Static(winrt._winrt.IInspectable_Static):
    # System.Boolean Windows.Phone.System.Profile.RetailMode::get_RetailModeEnabled()
    @_property
    def retail_mode_enabled(cls) -> bool: ...

@typing.final
class RetailMode(winrt.system.Object, metaclass=RetailMode_Static):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import winrt.system
from winrt._winrt_windows_phone_system_profile import (
    RetailMode,
)

__all__ = [
    "RetailMode",
]

